/*
** Module   : LegacyFieldNameMap.java
** Abstract : Bi-directional runtime mapping of DMO properties to their associated (lower case)
**            legacy field names.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 VMN 20140409 Created initial version.
*/

package com.goldencode.p2j.persist;

import java.util.*;

/**
 * This class performs a bi-directional runtime mapping of DMO properties to their associated
 * (lower case) legacy field names.
 */
public class LegacyFieldNameMap
{
   /** Mapping of the legacy fields to (lower case) DMO property names. */
   private Map<String, String> legacyField2Name;

   /** Mapping of (lower case) DMO property names to legacy fields. */
   private Map<String, String> name2LegacyField;

   /**
    * Constructor.
    *
    * @param   legacyField2Name
    *          Map of the legacy fields to (lower case) DMO property names.
    * @param   name2LegacyField
    *          Map of (lower case) DMO property names to legacy fields.
    */
   public LegacyFieldNameMap(Map<String, String> legacyField2Name,
                             Map<String, String> name2LegacyField)
   {
      this.legacyField2Name = legacyField2Name;
      this.name2LegacyField = name2LegacyField;
   }

   /**
    * Get map of the legacy fields to (lower case) DMO property names.
    *
    * @return  Map of the legacy fields to (lower case) DMO property names.
    */
   public Map<String, String> getLegacyField2Name()
   {
      return legacyField2Name;
   }

   /**
    * Get map of (lower case) DMO property names to legacy fields.
    *
    * @return  Map of (lower case) DMO property names to legacy fields.
    */
   public Map<String, String> getName2LegacyField()
   {
      return name2LegacyField;
   }
}
